@@ -11,7 +11,7 @@ use Scalar::Util qw( looks_like_number );
 
 use Git::Repository::Command;
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 # a few simple accessors
 for my $attr (qw( git_dir work_tree options )) {
@@ -47,6 +47,9 @@ sub new {
     my %arg = grep { !( ref eq 'HASH' ? $self->{options} ||= $_ : 0 ) } @arg;
     my $options = $self->{options} ||= {};
 
+    # ignore 'input' option during object creation
+    my $input = delete $options->{input};
+
     # setup default options
     # accept older for backward compatibility
     my ($git_dir) = grep {defined} delete @arg{qw( git_dir repository )};
@@ -119,6 +122,9 @@ sub new {
     croak "fatal: Not a git repository: $self->{git_dir}"
         if $self->{git_dir} ne $gitdir;
 
+    # put back the ignored option
+    $options->{input} = $input if defined $input;
+
     return $self;
 }
 
@@ -358,6 +364,12 @@ So this:
 will be equivalent to having any option hash that will be passed to
 C<run()> or C<command()> be pre-filled with these options.
 
+It probably makes no sense to set the C<input> option in C<new()> or
+C<create()>, but C<Git::Repository> won't stop you.
+Note that on some systems, some git commands may close standard input
+on startup, which will cause a SIGPIPE. C<Git::Repository::Command>
+will raise an exception.
+
 =head2 create( @cmd )
 
 Runs a repository initializing command (like C<init> or C<clone>) and
